<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>YtbInputFactory</name>
    <message>
        <location filename="../ytbinputfactory.cpp" line="36"/>
        <source>Youtube Plugin</source>
        <translation>Módulo Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="70"/>
        <source>About Youtube Transport Plugin</source>
        <translation>Acerca del Módulo de Transporte Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="71"/>
        <source>Qmmp Youtube Transport Plugin</source>
        <translation>Módulo de Transporte Youtube de Qmmp</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="72"/>
        <source>This plugin adds feature to play audio from Youtube using %1 utility</source>
        <translation>Este complemento añade funciones para reproducir audio desde Youtube utilizando la herramienta %1</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="74"/>
        <source>%1 version: %2</source>
        <translation>%1 versión: %2</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="75"/>
        <source>Written by: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation>Escrito por: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
    </message>
</context>
<context>
    <name>YtbInputSource</name>
    <message>
        <location filename="../ytbinputsource.cpp" line="185"/>
        <source>Uploader</source>
        <translation>Subido por</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="186"/>
        <source>Upload date</source>
        <translation>Fecha de subida</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="187"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
</TS>
